pub struct Wal { /* private fields */ }Expand description
Write-Ahead Log manager
Implementations
Sourceimpl Wal
impl Wal
Sourcepub fn set_sync_mode(&mut self, sync: bool)
pub fn set_sync_mode(&mut self, sync: bool)
Set sync mode
Sourcepub fn current_sequence(&self) -> u64
pub fn current_sequence(&self) -> u64
Get current sequence number
Returns the current WAL sequence number which increments with each write. This is needed by PersistenceManager::checkpoint() to record the actual checkpoint sequence instead of always using 0, which was causing misleading output in the banking demo (WAL checkpoint always showed sequence 0).